@@ -6,7 +6,16 @@ import chalk from '../source/index.js';
 for (const key of Object.keys(styles)) {
 	let returnValue = key;
 
-	if (key === 'reset' || key === 'hidden' || key === 'grey') {
+	// We skip `overline` as almost no terminal supports it so we cannot show it off.
+	if (
+		key === 'reset'
+			|| key === 'hidden'
+			|| key === 'grey'
+			|| key === 'bgGray'
+			|| key === 'bgGrey'
+			|| key === 'overline'
+			|| key.endsWith('Bright')
+	) {
 		continue;
 	}
 
